@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.58';
+our $VERSION = '0.5801';
 
 use warnings;
 use strict;
@@ -226,7 +226,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.58
+version 0.5801
 
 =head1 SYNOPSIS
 
@@ -294,23 +294,26 @@ Please see L<Graph> for the possible constructor arguments.
 =head2 populate()
 
   $gw->populate($matrix);
+  $gw->populate($matrix, $attribute);
   $gw->populate(\@vectors);
   $gw->populate(\@vectors, $attribute);
+  $gw->populate(\%data_points);
   $gw->populate(\%data_points, $attribute);
 
 Populate a graph with weighted nodes.
 
-For arguments, the data can be a numeric value ("terminal node"), an arrayref
-of numeric vectors, a C<Math::MatrixReal> object, or a hashref of numeric edge
-values.  The C<attribute> is an optional string name, with the default "weight."
+For arguments, the data can be an arrayref of numeric vectors, a
+C<Math::MatrixReal> object, or a hashref of numeric edge values.  The
+C<attribute> is an optional string name, with the default "weight."
 
-Examples of C<data> in array reference form:
+Examples of vertices in array reference form:
 
   []      1 vertex with no edges.
-  [0]     1 vertex and 1 edge to node 0 having weight of 0.
-  [1]     1 vertex and 1 edge to node 0 weight 1.
-  [0,1]   2 vertices and 2 edges having edge weights 0,1 and vertex weight 1.
-  [0,1,9] 3 vertices and 3 edges having edge weights 0,1,9 and vertex weight 10.
+  [0]     1 vertex with no edges.
+  [1]     1 vertex and 1 edge to itself, weight 1.
+  [0,1]   1 vertex and 1 edge, weight 1.
+  [1,0,9] 2 vertices and 2 edges having, weight 10.
+  [1,2,3] 3 vertices and 3 edges having, weight 6.
 
 Multiple attributes may be applied to a graph, thereby layering and increasing
 the overall dimension.
